#[repr(u8)]pub enum Ocram2TzEn {
OCRAM2_TZ_EN_0 = 0,
OCRAM2_TZ_EN_1 = 1,
}Variants
OCRAM2_TZ_EN_0 = 0
The TrustZone feature is disabled. Entire OCRAM2 space is available for all access types (secure/non-secure/user/supervisor).
OCRAM2_TZ_EN_1 = 1
The TrustZone feature is enabled. Access to address in the range specified by [ENDADDR:STARTADDR] follows the execution mode access policy described in CSU chapter.
Implementations
Sourceimpl Ocram2TzEn
impl Ocram2TzEn