#[repr(u8)]pub enum OcramTzEn {
OCRAM_TZ_EN_0 = 0,
OCRAM_TZ_EN_1 = 1,
}Variants
OCRAM_TZ_EN_0 = 0
The TrustZone feature is disabled. Entire OCRAM space is available for all access types (secure/non-secure/user/supervisor).
OCRAM_TZ_EN_1 = 1
The TrustZone feature is enabled. Access to address in the range specified by [ENDADDR:STARTADDR] follows the execution mode access policy described in CSU chapter.
Implementations